@@ -14,7 +14,8 @@ NULL
 #' that will arrange \code{n} panels in a single plot. 
 #' 
 #' @param n number of plots to be arranged.
-#' 
+#'
+#' @return a 2-long numeric vector that can be passed to `par(mfrow = <value>)`.
 #' @rdname graphics-utils
 #' @export
 #' @examples
@@ -25,7 +26,7 @@ NULL
 #' mfrow(4)
 #' mfrow(10)
 mfrow <- function(n){
-	if( n == 1 ) 1
+	if( n == 1 ) c(1, 1)
 	else if( n == 2 ) c(1, 2)
 	else if( n <= 4 ) c(2, 2)
 	else if( n <= 6 ) c(3, 2)
@@ -36,3 +37,14 @@ mfrow <- function(n){
 	}
 }
 
+round.pretty <- function(x, min=2){
+	
+	if( is.null(x) ) return(NULL)		
+	n <- 0
+	y <- round(sort(x), n)
+	while( any(diff(y)==0) ){
+		n <- n+1
+		y <- round(sort(x), n)
+	}	
+	round(x, max(min,n))
+}
